Generator

Trait Generator 

pub trait Generator {
    // Required methods
    fn method_1(&mut self) -> Pokemon;
    fn method_2(&mut self) -> Pokemon;
    fn method_4(&mut self) -> Pokemon;
}

Required Methods

fn method_1(&mut self) -> Pokemon

Four RNG calls are made, two to generate the PID and two to generate the IVs. It can be illustrated as [PID] [PID] [IVs] [IVs].

fn method_2(&mut self) -> Pokemon

Five RNG calls are made. The first two are used to generate the PID and the last two are used to generate the IVs. The third RNG call is not used for anything. It can be illustrated as [PID] [PID] [xxxx] [IVs] [IVs].

fn method_4(&mut self) -> Pokemon

Five RNG calls are made. The first and second are used to generate the PID and the third and fifth are used to generate the IVs. The fourth RNG call is not used for anything. It can be illustrated as [PID] [PID] [IVs] [xxxx] [IVs].

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors